@@ -84,12 +84,12 @@ tq_transmute_.tbl_df <- function(data, select = NULL, mutate_fun, col_rename = N
     if (is_period_fun) {
         # Add arg: OHLC = FALSE
         ret <- data %>%
-            as_xts_(date_col = date_col_name) %>%
+            timetk::tk_xts_(silent = TRUE) %>%
             fun_transmute(OHLC = FALSE, ...)
 
     } else {
         ret <- data %>%
-            as_xts_(date_col = date_col_name) %>%
+            timetk::tk_xts_(silent = TRUE) %>%
             fun_transmute(...)
     }
 
@@ -104,7 +104,7 @@ tq_transmute_.tbl_df <- function(data, select = NULL, mutate_fun, col_rename = N
 tq_transmute_.data.frame <- function(data, select = NULL, mutate_fun, col_rename = NULL, ...) {
 
     # Convert data.frame to tibble
-    data <- as_tibble(data)
+    data <- tibble::as_tibble(data)
 
     # Call tq_transmute_ for a tibble
     tq_transmute_(data          = data,
@@ -195,11 +195,11 @@ tq_transmute_xy_.tbl_df <- function(data, x, y = NULL, mutate_fun, col_rename =
         # Add arg: OHLC = FALSE
         if (y == "NULL" || is.null(y)) {
             ret <- data %>%
-                as_xts_(date_col = date_col_name) %$%
+                timetk::tk_xts_(silent = TRUE) %$%
                 fun_transmute(eval(parse(text = x)), OHLC = FALSE, ...)
         } else {
             ret <- data %>%
-                as_xts_(date_col = date_col_name) %$%
+                timetk::tk_xts_(silent = TRUE) %$%
                 fun_transmute(eval(parse(text = x)),
                               eval(parse(text = y)),
                               OHLC = FALSE,
@@ -208,12 +208,12 @@ tq_transmute_xy_.tbl_df <- function(data, x, y = NULL, mutate_fun, col_rename =
     } else {
         if (y == "NULL" || is.null(y)) {
             ret <- data %>%
-                as_xts_(date_col = date_col_name) %$%
+                timetk::tk_xts_(silent = TRUE) %$%
                 # OHLCV() %$%
                 fun_transmute(eval(parse(text = x)), ...)
         } else {
             ret <- data %>%
-                as_xts_(date_col = date_col_name) %$%
+                timetk::tk_xts_(silent = TRUE) %$%
                 # OHLCV() %$%
                 fun_transmute(eval(parse(text = x)),
                               eval(parse(text = y)),
@@ -232,7 +232,7 @@ tq_transmute_xy_.tbl_df <- function(data, x, y = NULL, mutate_fun, col_rename =
 tq_transmute_xy_.data.frame <- function(data, x, y = NULL, mutate_fun, col_rename = NULL, ...) {
 
     # Convert data.frame to tibble
-    data <- as_tibble(data)
+    data <- tibble::as_tibble(data)
 
     # Call tq_transmute_xy_ for a tibble
     tq_transmute_xy_(data          = data,
@@ -333,14 +333,13 @@ coerce_to_tibble <- function(data, date_col_name, time_zone, col_rename) {
 
     # Coerce to tibble
     ret <- data %>%
-        as_tibble(preserve_row_names = TRUE) %>%
-        dplyr::rename(date = row.names)
+        timetk::tk_tbl(preserve_index = TRUE, rename_index = date_col_name, silent = TRUE)
 
-    # Convert to date
-    ret <- convert_date_cols(ret, time_zone)
+    # # Convert to date
+    # ret <- convert_date_cols(ret, time_zone)
 
-    # Rename row.names
-    names(ret)[[1]] <- date_col_name
+    # # Rename row.names
+    # names(ret)[[1]] <- date_col_name
 
     # Rename columns
     if (!is.null(col_rename)) {
